@@ -1,24 +1,10 @@
-/*****************************************************************************
-  This file is part of the game 'KJumpingCube'
+/*
+    This file is part of the game 'KJumpingCube'
 
-  Copyright (C) 1998-2000 by Matthias Kiefer
-                            <matthias.kiefer@gmx.de>
+    SPDX-FileCopyrightText: 1998-2000 Matthias Kiefer <matthias.kiefer@gmx.de>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
-
-**************************************************************************** */
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "kjumpingcube.h"
 #include "kcubeboxwidget.h"
@@ -83,34 +69,38 @@ void KJumpingCube::initKAction() {
   QAction * action;
 
   QSignalMapper * gameMapper = new QSignalMapper (this);
-  connect (gameMapper, SIGNAL (mapped(int)), m_game, SLOT (gameActions(int)));
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+  connect (gameMapper, &QSignalMapper::mappedInt, m_game, &Game::gameActions);
+#else
+  connect (gameMapper, QOverload<int>::of(&QSignalMapper::mapped), m_game, &Game::gameActions);
+#endif
 
-  action = KStandardGameAction::gameNew (gameMapper, SLOT (map()), this);
+  action = KStandardGameAction::gameNew (gameMapper, QOverload<>::of(&QSignalMapper::map), this);
   actionCollection()->addAction (action->objectName(), action);
   gameMapper->setMapping (action, NEW);
 
-  action = KStandardGameAction::load    (gameMapper, SLOT (map()), this);
+  action = KStandardGameAction::load    (gameMapper, QOverload<>::of(&QSignalMapper::map), this);
   actionCollection()->addAction (action->objectName(), action);
   gameMapper->setMapping (action, LOAD);
 
-  action = KStandardGameAction::save    (gameMapper, SLOT (map()), this);
+  action = KStandardGameAction::save    (gameMapper, QOverload<>::of(&QSignalMapper::map), this);
   actionCollection()->addAction (action->objectName(), action);
   gameMapper->setMapping (action, SAVE);
 
-  action = KStandardGameAction::saveAs  (gameMapper, SLOT (map()), this);
+  action = KStandardGameAction::saveAs  (gameMapper, QOverload<>::of(&QSignalMapper::map), this);
   actionCollection()->addAction (action->objectName(), action);
   gameMapper->setMapping (action, SAVE_AS);
 
-  action = KStandardGameAction::hint    (gameMapper, SLOT(map()), this);
+  action = KStandardGameAction::hint    (gameMapper, QOverload<>::of(&QSignalMapper::map), this);
   actionCollection()->addAction (action->objectName(), action);
   gameMapper->setMapping (action, HINT);
 
-  action = KStandardGameAction::undo    (gameMapper, SLOT (map()), this);
+  action = KStandardGameAction::undo    (gameMapper, QOverload<>::of(&QSignalMapper::map), this);
   actionCollection()->addAction (action->objectName(), action);
   gameMapper->setMapping (action, UNDO);
   action->setEnabled (false);
 
-  action = KStandardGameAction::redo    (gameMapper, SLOT (map()), this);
+  action = KStandardGameAction::redo    (gameMapper, QOverload<>::of(&QSignalMapper::map), this);
   actionCollection()->addAction (action->objectName(), action);
   gameMapper->setMapping (action, REDO);
   action->setEnabled (false);
@@ -128,7 +118,7 @@ void KJumpingCube::initKAction() {
        "QPushButton#ActionButton:disabled { color: white;"
             "border-color: beige; background-color: steelblue; }");
   gameMapper->setMapping (actionButton, BUTTON);
-  connect (actionButton, SIGNAL(clicked()), gameMapper, SLOT(map()));
+  connect (actionButton, &QAbstractButton::clicked, gameMapper, QOverload<>::of(&QSignalMapper::map));
 
   QWidgetAction *widgetAction = new QWidgetAction(this);
   widgetAction->setDefaultWidget(actionButton);
@@ -137,12 +127,12 @@ void KJumpingCube::initKAction() {
   changeButton (true, true);		// Load the button's style sheet.
   changeButton (false);			// Set the button to be inactive.
 
-  action = KStandardAction::preferences (m_game, SLOT(showSettingsDialog()),
+  action = KStandardAction::preferences (m_game, [this]() { m_game->showSettingsDialog(true); },
                                          actionCollection());
   qCDebug(KJUMPINGCUBE_LOG) << "PREFERENCES ACTION is" << action->objectName();
   action->setIconText (i18n("Settings"));
 
-  action = KStandardGameAction::quit (this, SLOT (close()), this);
+  action = KStandardGameAction::quit (this, &KJumpingCube::close, this);
   actionCollection()->addAction (action->objectName(), action);
 
   setupGUI();
